function OverdampedBeadRotatingHoop(gamma)
% ======================================================================= %
% Plots the function f(phi) = (gamma*cos(phi)-1)*sin(phi).
% If no input is given, it does a slide show; with gamma from 0 to 2.
% Here you can see how a triple zero appears for gamma = 1, and splits
% into three betond ---> soft pitchfork bifurcation.
% ======================================================================= %
if nargin == 0;
   figure; whitebg(gcf, 'w');
   gamma = (0:20)/10;
   for n=1:21;
     OverdampedBeadRotatingHoop(gamma(n)); pause(0.5);
   end
   return
end;
N = 200;
phi = -pi + 2*pi*(0:N)/N;
f   = (gamma*cos(phi)-1).*sin(phi);
FZ  = 'FontSize';
%
ltxt = '-k';
if gamma < 1; ltxt = '-r'; end
if gamma > 1; ltxt = '-b'; end
plot(phi, f, ltxt, 'LineWidth', 3); grid on;
xlabel('{\bf \phi}', FZ, 18)
ylabel('{\bf f(\phi ) }', FZ, 18, 'rotation', 0)
ttxt = '{\bf Overdamped bead function for \gamma = ';
title([ttxt, num2str(gamma), ' }'], FZ, 18)
set(gca, 'FontWeight', 'bold', FZ, 12)
axis([-pi, pi, -1.8, 1.8])
% END